@@ -1,5 +1,5 @@
 # -*- coding: utf-8 -*-
-# Copyright (c) 2017-2021 Richard Hull and contributors
+# Copyright (c) 2017-2022 Richard Hull and contributors
 # See LICENSE.rst for details.
 
 import atexit
@@ -8,8 +8,6 @@ import argparse
 import importlib
 from collections import OrderedDict
 
-from deprecated import deprecated
-
 
 def get_choices(module_name):
     """
@@ -214,11 +212,6 @@ class make_interface(object):
         return GPIO
 
 
-@deprecated(version='1.17.1', reason="Use 'make_interface' class instead")
-class make_serial(make_interface):
-    pass
-
-
 def create_device(args, display_types=None):
     """
     Create and return device.
